# user_management/symptom_analysis/data.py

symptom_to_condition = {
    "sneezing": ["Dust Allergy", "Pollen Allergy"],
    "itchy skin": ["Eczema", "Food Allergy"],
    "headache": ["Vitamin D Deficiency", "Sinus Allergy"],
    "fatigue": ["Iron Deficiency", "Vitamin B12 Deficiency"],
    "hives": ["Insect Allergy", "Food Allergy"],
    "nausea": ["Lactose Intolerance", "Food Sensitivity"],
    "shortness of breath": ["Asthma", "Pollen Allergy"],
    "skin rash" : ["skin allergy", "Dust Allergy"],
    "itching": ["Pollen Allergy", "Dust Allergy"],
    "chest pain": ["Heart Disease", "Gastritis"],
}
